@@ -4,7 +4,6 @@
 use std::{fs, path::Path};
 
 use chrono::NaiveDateTime;
-use deepspeech::Model;
 use log::{error, info};
 use rand::{distributions::Alphanumeric, prelude::*};
 use sqlx::PgPool;
@@ -85,12 +84,15 @@ impl Clip {
         btfm_data_dir: &Path,
         file: &Path,
         description: &str,
-        deepspeech_model: &Path,
-        deepspeech_external_scorer: &Path,
+        phrase: &str,
     ) -> Result<Clip, crate::Error> {
         let mut file_prefix = "clips/".to_owned();
-        let random_prefix: String = thread_rng().sample_iter(&Alphanumeric).take(6).collect();
-        file_prefix.push_str(random_prefix.as_str());
+        let random_prefix: String = thread_rng()
+            .sample_iter(&Alphanumeric)
+            .take(6)
+            .map(char::from)
+            .collect();
+        file_prefix.push_str(&random_prefix);
         let file_name = file_prefix
             + "-"
             + file
@@ -101,16 +103,6 @@ impl Clip {
         let clip_destination = btfm_data_dir.join(&file_name);
         fs::copy(&file, &clip_destination).expect("Unable to copy clip to data directory");
 
-        let ds_model =
-            Model::load_from_files(&deepspeech_model).expect("Unable to load deepspeech model");
-        let audio = crate::voice::file_to_wav(&clip_destination, ds_model.get_sample_rate()).await;
-        let phrase = crate::voice::voice_to_text(
-            deepspeech_model.to_owned(),
-            Some(deepspeech_external_scorer.to_owned()),
-            audio,
-        )
-        .await;
-
         let insert_result = sqlx::query!(
             "
             INSERT INTO clips (phrase, description, audio_file)
@@ -126,7 +118,7 @@ impl Clip {
         match insert_result {
             Ok(insert) => {
                 info!("Added clip for {}", &file_name);
-                return Ok(Clip {
+                Ok(Clip {
                     id: insert.id,
                     created_on: insert.created_on,
                     last_played: insert.last_played,
@@ -134,9 +126,9 @@ impl Clip {
                     phrase: insert.phrase,
                     description: insert.description,
                     audio_file: insert.audio_file,
-                });
+                })
             }
-            Err(e) => return Err(crate::Error::Database(e)),
+            Err(e) => Err(crate::Error::Database(e)),
         }
     }
 
@@ -577,8 +569,8 @@ pub async fn last_play_time(pool: &PgPool) -> NaiveDateTime {
     .fetch_one(pool)
     .await;
     match clip_query {
-        Ok(clip) => return clip.last_played,
-        Err(_) => return NaiveDateTime::from_timestamp(0, 0),
+        Ok(clip) => clip.last_played,
+        Err(_) => NaiveDateTime::from_timestamp(0, 0),
     }
 }
 
